@@ -6,10 +6,13 @@ from collections import OrderedDict
 
 from django.conf import settings
 from django.contrib.sites.models import Site
+from django.core.files.storage import get_storage_class
 from django.http.request import HttpRequest
 from django.middleware.csrf import get_token
 from django.utils.translation import get_language_from_request
 
+from richie.apps.core.templatetags.joanie import is_joanie_enabled
+from richie.apps.courses.defaults import RICHIE_MAX_ARCHIVED_COURSE_RUNS
 from richie.apps.courses.models import Organization
 
 from . import defaults
@@ -44,6 +47,7 @@ def site_metas(request: HttpRequest):
                 "environment": getattr(settings, "ENVIRONMENT", ""),
                 "release": getattr(settings, "RELEASE", ""),
                 "sentry_dsn": getattr(settings, "SENTRY_DSN", ""),
+                **WebAnalyticsContextProcessor().frontend_context_processor(request),
             }
         },
         **WebAnalyticsContextProcessor().context_processor(request),
@@ -52,11 +56,12 @@ def site_metas(request: HttpRequest):
     if getattr(settings, "CDN_DOMAIN", None):
         context["CDN_DOMAIN"] = settings.CDN_DOMAIN
 
+    storage_url = get_storage_class()().url("any-page")
     # Add a MEDIA_URL_PREFIX to context to prefix the media url files to have an absolute URL
-    if settings.MEDIA_URL.startswith("//"):
+    if storage_url.startswith("//"):
         # Eg. //my-cdn-user.cdn-provider.com/media/
         context["MEDIA_URL_PREFIX"] = f"{request.scheme:s}:"
-    elif settings.MEDIA_URL.startswith("/"):
+    elif storage_url.startswith("/"):
         # Eg. /media/
         context["MEDIA_URL_PREFIX"] = f"{protocol:s}://{site_current.domain:s}"
     else:
@@ -91,6 +96,11 @@ def site_metas(request: HttpRequest):
             "backend": authentication_delegation["BACKEND"],
         }
 
+    if is_joanie_enabled():
+        context["FRONTEND_CONTEXT"]["context"]["joanie_backend"] = {
+            "endpoint": settings.JOANIE["BASE_URL"],
+        }
+
     if getattr(settings, "RICHIE_LMS_BACKENDS", None):
         context["FRONTEND_CONTEXT"]["context"]["lms_backends"] = [
             {
@@ -102,6 +112,16 @@ def site_metas(request: HttpRequest):
         ]
 
     context["FRONTEND_CONTEXT"] = json.dumps(context["FRONTEND_CONTEXT"])
+
+    if getattr(settings, "RICHIE_MINIMUM_COURSE_RUNS_ENROLLMENT_COUNT", None):
+        context[
+            "RICHIE_MINIMUM_COURSE_RUNS_ENROLLMENT_COUNT"
+        ] = settings.RICHIE_MINIMUM_COURSE_RUNS_ENROLLMENT_COUNT
+
+    context["RICHIE_MAX_ARCHIVED_COURSE_RUNS"] = getattr(
+        settings, "RICHIE_MAX_ARCHIVED_COURSE_RUNS", RICHIE_MAX_ARCHIVED_COURSE_RUNS
+    )
+
     return context
 
 
@@ -111,6 +131,18 @@ class WebAnalyticsContextProcessor:
     frontend.
     """
 
+    # pylint: disable=no-self-use
+    def frontend_context_processor(self, request: HttpRequest) -> dict:
+        """
+        Additional web analytics information for the frontend react
+        """
+        context = {}
+        if getattr(settings, "WEB_ANALYTICS_ID"):
+            context["web_analytics_provider"] = getattr(
+                settings, "WEB_ANALYTICS_PROVIDER", "google_analytics"
+            )
+        return context
+
     def context_processor(self, request: HttpRequest) -> dict:
         """
         Real implementation of the context processor for the Web Analytics core app sub-module
@@ -180,7 +212,7 @@ class WebAnalyticsContextProcessor:
         dimensions["course_runs_titles"] = [
             course_run.title
             for course_run in course_runs
-            if course_run is not None and course_run.title is not None
+            if course_run is not None and course_run.safe_title is not None
         ]
 
         dimensions["course_runs_resource_links"] = map(
