@@ -53,6 +53,8 @@ class CourseRunAdminForm(TranslatableModelForm):
             "enrollment_start",
             "enrollment_end",
             "languages",
+            "enrollment_count",
+            "catalog_visibility",
         ]
 
     def __init__(self, *args, **kwargs):
@@ -138,6 +140,8 @@ class CourseRunAdmin(FrontendEditableAdminMixin, TranslatableAdmin):
         "enrollment_start",
         "enrollment_end",
         "languages",
+        "enrollment_count",
+        "catalog_visibility",
     )
     list_display = ["id"]
     form = CourseRunAdminForm
