@@ -6,9 +6,9 @@ from collections.abc import Mapping
 from datetime import MAXYEAR, datetime
 
 from django.conf import settings
-from django.core.exceptions import ValidationError
+from django.core.exceptions import ObjectDoesNotExist, ValidationError
 from django.db import models
-from django.db.models import Q
+from django.db.models import Q, Sum
 from django.urls import reverse
 from django.utils import timezone
 from django.utils.functional import cached_property, lazy
@@ -27,7 +27,7 @@ from ...core.defaults import ALL_LANGUAGES
 from ...core.fields.duration import CompositeDurationField
 from ...core.fields.multiselect import MultiSelectField
 from ...core.helpers import get_permissions
-from ...core.models import BasePageExtension
+from ...core.models import BasePageExtension, EsIdMixin
 from .. import defaults, utils
 from .category import Category, CategoryPluginModel
 from .organization import Organization, OrganizationPluginModel
@@ -136,7 +136,7 @@ class CourseState(Mapping):
 
 
 # pylint: disable=too-many-public-methods
-class Course(BasePageExtension):
+class Course(EsIdMixin, BasePageExtension):
     """
     The course page extension represents and records a course in the catalog.
 
@@ -209,6 +209,9 @@ class Course(BasePageExtension):
     @property
     def pt_effort(self):
         """Return effort as a PT string for schema.org metadata."""
+        if not self.effort:
+            return ""
+
         (effort, effort_unit) = self.effort
         unit_letter = effort_unit[0].upper()
         return f"PT{effort:d}{unit_letter:s}"
@@ -461,6 +464,24 @@ class Course(BasePageExtension):
             direct_course__extended_object__publisher_is_draft=is_draft,
         ).order_by("-start")
 
+    @cached_property
+    def course_runs_enrollment_count(self):
+        """
+        Returns a query that sum the enrollment count of each course run. They may be directly
+        related to the course or to a snapshot of the course.
+
+        The draft and the public page have their own course runs. The course runs on the draft
+        page are copied to the public page when the course is published (for any language).
+        """
+        is_draft = self.extended_object.publisher_is_draft
+        node = self.extended_object.node
+        current_and_descendant_nodes = node.__class__.get_tree(parent=node)
+
+        return CourseRun.objects.filter(
+            direct_course__extended_object__node__in=current_and_descendant_nodes,
+            direct_course__extended_object__publisher_is_draft=is_draft,
+        ).aggregate(sum=Sum("enrollment_count"))["sum"]
+
     @property
     def course_runs_dict(self):
         """Returns a dict of course runs grouped by their state."""
@@ -639,6 +660,18 @@ class CourseRunSyncMode(models.TextChoices):
     SYNC_TO_PUBLIC = "sync_to_public", _("Synchronization to public page")
 
 
+class CourseRunCatalogVisibility(models.TextChoices):
+    """Course run catalog visibility choices."""
+
+    COURSE_AND_SEARCH = "course_and_search", _(
+        "course_and_search - show on the course page and include in search results"
+    )
+    COURSE_ONLY = "course_only", _(
+        "course_only - show on the course page and hide from search results"
+    )
+    HIDDEN = "hidden", _("hidden - hide on the course page and from search results")
+
+
 class CourseRun(TranslatableModel):
     """
     The course run represents and records the occurence of a course between a start
@@ -683,6 +716,19 @@ class CourseRun(TranslatableModel):
         choices=lazy(lambda: ALL_LANGUAGES, tuple)(),
         help_text=_("The list of languages in which the course content is available."),
     )
+    enrollment_count = models.PositiveIntegerField(
+        _("enrollment count"),
+        default=0,
+        blank=True,
+        help_text=_("The number of enrolled students"),
+    )
+    catalog_visibility = models.CharField(
+        _("catalog visibility"),
+        choices=CourseRunCatalogVisibility.choices,
+        default=CourseRunCatalogVisibility.COURSE_AND_SEARCH,
+        blank=False,
+        max_length=20,
+    )
 
     class Meta:
         db_table = "richie_course_run"
@@ -848,6 +894,21 @@ class CourseRun(TranslatableModel):
             extended_object__publisher_is_draft=is_draft,
         ).distinct()[0]
 
+    @property
+    def safe_title(self):
+        """
+        Access the `title` translatable field from the `CourseRunTranslation` on a safe way.
+        """
+        try:
+            return self.title
+        except ObjectDoesNotExist:
+            return None
+
+    @property
+    def is_visible_on_course_page(self):
+        """Return True if the course run is visible on the course page"""
+        return self.catalog_visibility != CourseRunCatalogVisibility.HIDDEN
+
 
 class CourseRunTranslation(TranslatedFieldsModel):
     """
