@@ -128,8 +128,8 @@ CMS_PLACEHOLDER_CONF = {
     },
     "courses/cms/course_detail.html course_teaser": {
         "name": _("Teaser"),
-        "plugins": ["VideoPlayerPlugin", "SimplePicturePlugin"],
-        "limits": {"VideoPlayerPlugin": 1, "SimplePicturePlugin": 1},
+        "plugins": ["VideoPlayerPlugin"],
+        "limits": {"VideoPlayerPlugin": 1},
     },
     "courses/cms/course_detail.html course_description": {
         "name": _("About the course"),
@@ -442,7 +442,7 @@ DJANGOCMS_VIDEO_TEMPLATES = [("full-width", _("Full width"))]
 
 # Richie plugins
 
-RICHIE_PLAINTEXT_MAXLENGTH = {"course_introduction": 200, "bio": 150, "excerpt": 200}
+RICHIE_PLAINTEXT_MAXLENGTH = {"course_introduction": 200, "bio": 150, "excerpt": 240}
 
 RICHIE_SIMPLETEXT_CONFIGURATION = [
     {
