@@ -3,10 +3,13 @@ import re
 from operator import itemgetter
 
 from django import forms
+from django.core.cache import caches
+from django.core.cache.backends.base import InvalidCacheBackendError
 from django.core.exceptions import ImproperlyConfigured
-from django.utils import timezone, translation
+from django.utils import translation
 from django.utils.translation import gettext as _
 
+import arrow
 from cms.api import Page
 
 from richie.apps.core.defaults import ALL_LANGUAGES_DICT
@@ -72,9 +75,32 @@ class IndexableFilterDefinition(TermsQueryMixin, BaseFilterDefinition):
         Build the aggregations as a term query that counts all the different values assigned
         to the field.
         """
-        # Look for an include parameter in the form data and default to the regex returned
-        # by the `aggs_include` property:
-        include = data[f"{self.name:s}_include"] or self.aggs_include
+        # Look the aggregations parameters in the form data (either [filter]_children_aggs or
+        # [filter]_aggs), and default to the filter definition's aggs_include.
+        if data[f"{self.name:s}_children_aggs"]:
+            # Cache the request for children of the relevant parent
+            parent_id = data[f"{self.name:s}_children_aggs"]
+            cache_key = f"filter_definition_{self.name}_aggs_include_{parent_id}"
+            try:
+                cache = caches["search"]
+                include = cache.get(cache_key)
+            except InvalidCacheBackendError:
+                cache = None
+                include = None
+
+            if include is None:
+                # Add all child pages of the given parent to the included aggs
+                include = [
+                    str(page_id)
+                    for page_id in Page.objects.get(id=parent_id)
+                    .get_child_pages()
+                    .values_list("id", flat=True)
+                ]
+                if cache is not None:
+                    cache.set(cache_key, include)
+
+        else:
+            include = data[f"{self.name:s}_aggs"] or self.aggs_include
 
         # Use all the query fragments from the queries *but* the one(s) that filter on the
         # current filter
@@ -122,6 +148,21 @@ class IndexableFilterDefinition(TermsQueryMixin, BaseFilterDefinition):
             }
         }
 
+        def value_included(value, include):
+            """
+            Do not build aggregations for values from query string if they do not match
+            the current include filter.
+            Use a function to perform the check as the include filter can be either a regex
+            or a list.
+            """
+            try:
+                # The Elasticsearch include regex matches exact values so we must do the same
+                # by adding ^ (resp. $) at the beginning (resp. at the end) of the pattern.
+                return re.match(f"^{include:s}$", value)
+            # Trying to build the regex with a list will trigger a TypeError
+            except TypeError:
+                return value in include
+
         # Filters aggregation for values that were selected in the querystring (we must force
         # them because they may not be in the n top facet counts but we must make sure we keep
         # them so that they remain available as options that the user can see and unselect)
@@ -142,9 +183,7 @@ class IndexableFilterDefinition(TermsQueryMixin, BaseFilterDefinition):
                     }
                 }
                 for value in data.get(self.name, [])
-                # The Elasticsearch include regex matches exact values so we must do the same
-                # by adding ^ (resp. $) at the beginning (resp. at the end) of the pattern.
-                if re.match(f"^{include:s}$", value)
+                if value_included(value, include)
             }
         )
 
@@ -154,16 +193,21 @@ class IndexableFilterDefinition(TermsQueryMixin, BaseFilterDefinition):
         """
         Indexables are filtered via:
         - a list of their Elasticsearch ids i.e strings,
-        - a regex to eventually limit which terms are facetted.
+        - a list of ES IDs for which we want to get aggregations,
+        - one filter whose children we want to use for aggregations.
         """
         return {
             self.name: (
                 ArrayField(required=False, base_type=forms.CharField(max_length=50)),
                 True,  # an ArrayField expects list values
             ),
-            f"{self.name:s}_include": (
-                forms.CharField(max_length=500, required=False),
-                False,  # a CharField expects string values
+            f"{self.name}_aggs": (
+                ArrayField(required=False, base_type=forms.CharField(max_length=50)),
+                True,  # an ArrayField expects list values
+            ),
+            f"{self.name}_children_aggs": (
+                forms.CharField(required=False, max_length=50),
+                False,
             ),
         }
 
@@ -302,14 +346,15 @@ class IndexableFilterDefinition(TermsQueryMixin, BaseFilterDefinition):
             for key, count in key_count_map.items()
         ]
 
+        sorting = data["facet_sorting"] or self.sorting
         # Sort facets as requested
-        if self.sorting == self.SORTING_NAME:
+        if sorting == self.SORTING_NAME:
             # Alphabetical ascending sorting
             values = sorted(
                 values,
                 key=lambda value: (value["human_name"], value["count"] * -1),
             )
-        elif self.sorting == self.SORTING_COUNT:
+        elif sorting == self.SORTING_COUNT:
             # Sorting by descending facet count
             values = sorted(
                 values,
@@ -319,7 +364,7 @@ class IndexableFilterDefinition(TermsQueryMixin, BaseFilterDefinition):
             # NB: self.SORTING_CONF is not appropriate for Indexables as they are not defined
             # in the static filter definition but generated from indices.
             raise ImproperlyConfigured(
-                f'Facet sorting "{self.sorting}" is invalid for filter {self.name}.'
+                f'Facet sorting "{sorting}" is invalid for filter {self.name}.'
             )
 
         return {
@@ -344,7 +389,7 @@ class IndexableFilterDefinition(TermsQueryMixin, BaseFilterDefinition):
         }
 
 
-class IndexableMPTTFilterDefinition(IndexableFilterDefinition):
+class IndexableHierarchicalFilterDefinition(IndexableFilterDefinition):
     """
     Some of our filters are a special case of terms-based filter as they use MPTT paths
     as IDs and enable limiting faceting by path.
@@ -353,24 +398,39 @@ class IndexableMPTTFilterDefinition(IndexableFilterDefinition):
     @property
     def aggs_include(self):
         """
-        Return a regex that limits what facets are computed on the field.
+        Return a list that limits what facets are computed on the field.
 
         Returns:
         --------
-            string: a regex depending on filters configuration in settings and pages in the CMS:
-            - "": the empty string, if the `reverse_id` does not correspond to any published
+            list: a list depending on filters configuration in settings and pages in the CMS:
+            - an empty list, if the `reverse_id` does not correspond to any published
                 page which will not match any value and return an empty list of facets,
-            - ".*-0001.{4}": if the `reverse_id` points to a published page with path "0001"
-                this will match ids of the children of this page that will be of the form
-                P-00010001 if they have children or L-00010001 if they are leafs,
-            ' ".*": if no `reverse_id` is set (delegated to super) which will
-                match all values.
+            - a list of ids of all direct children of the base page,
+            - ".*": if no `reverse_id` is set (delegated to super) which will match all values.
         """
         if self.reverse_id:
             if self.base_page:
-                node = self.base_page.node
-                return f".*-{node.path:s}.{{{node.steplen:d}}}"
-            return ""
+                cache_key = f"filter_definition_{self.name}_aggs_include"
+                try:
+                    cache = caches["search"]
+                    aggs_include = cache.get(cache_key)
+                except InvalidCacheBackendError:
+                    cache = None
+                    aggs_include = None
+
+                if aggs_include is None:
+                    # Add all the direct children of the base page to the included aggregations
+                    aggs_include = [
+                        str(page_id)
+                        for page_id in self.base_page.get_child_pages().values_list(
+                            "id", flat=True
+                        )
+                    ]
+                    if cache is not None:
+                        cache.set(cache_key, aggs_include)
+
+                return aggs_include
+            return []
 
         return super().aggs_include
 
@@ -418,19 +478,18 @@ class AvailabilityFilterDefinition(
 
     def get_fragment_map(self):
         """Return the hardcoded query fragments updated to the current datetime."""
+        now = arrow.utcnow().datetime
         return {
             self.OPEN: [
-                {"range": {"course_runs.enrollment_start": {"lte": timezone.now()}}},
-                {"range": {"course_runs.enrollment_end": {"gte": timezone.now()}}},
-            ],
-            self.COMING_SOON: [
-                {"range": {"course_runs.start": {"gte": timezone.now()}}}
+                {"range": {"course_runs.enrollment_start": {"lte": now}}},
+                {"range": {"course_runs.enrollment_end": {"gte": now}}},
             ],
+            self.COMING_SOON: [{"range": {"course_runs.start": {"gte": now}}}],
             self.ONGOING: [
-                {"range": {"course_runs.start": {"lte": timezone.now()}}},
-                {"range": {"course_runs.end": {"gte": timezone.now()}}},
+                {"range": {"course_runs.start": {"lte": now}}},
+                {"range": {"course_runs.end": {"gte": now}}},
             ],
-            self.ARCHIVED: [{"range": {"course_runs.end": {"lte": timezone.now()}}}],
+            self.ARCHIVED: [{"range": {"course_runs.end": {"lte": now}}}],
         }
 
 
